about summary refs log tree commit diff
path: root/src/libcore/io.rs
diff options
context:
space:
mode:
authorLindsey Kuper <lindsey@rockstargirl.org>2012-07-31 10:27:51 -0700
committerLindsey Kuper <lindsey@rockstargirl.org>2012-07-31 11:52:16 -0700
commit439afaa329751b3dfd6735862cd2645705598909 (patch)
tree4a3c51b47d6ee3c2e057677efdcf29c60e0d9d95 /src/libcore/io.rs
parentc2f49c46ae0b07aae8ae558d5a5e71ed85aeff23 (diff)
Change remaining "iface" occurrences to "trait"; deprecate "iface"
Diffstat (limited to 'src/libcore/io.rs')
-rw-r--r--src/libcore/io.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libcore/io.rs b/src/libcore/io.rs
index e83842232e6..510be3f89b9 100644
--- a/src/libcore/io.rs
+++ b/src/libcore/io.rs
@@ -27,8 +27,8 @@ extern mod rustrt {
 enum seek_style { seek_set, seek_end, seek_cur, }
 
 
-// The raw underlying reader iface. All readers must implement this.
-iface reader {
+// The raw underlying reader trait. All readers must implement this.
+trait reader {
     // FIXME (#2004): Seekable really should be orthogonal.
 
     // FIXME (#2982): This should probably return an error.
@@ -250,7 +250,7 @@ fn FILE_reader(f: *libc::FILE, cleanup: bool) -> reader {
     }
 }
 
 // FIXME (#2004): this should either be an iface-less impl, a set of
 // top-level functions that take a reader, or a set of default methods on
 // reader (which can then be called reader)
 
@@ -335,7 +335,7 @@ enum writer_type { screen, file }
 
 // FIXME (#2004): Seekable really should be orthogonal.
 // FIXME (#2004): eventually u64
-iface writer {
+trait writer {
     fn write(v: &[const u8]);
     fn seek(int, seek_style);
     fn tell() -> uint;
@@ -781,7 +781,7 @@ mod fsync {
     }
 
     // Type of objects that may want to fsync
-    iface t { fn fsync(l: level) -> int; }
+    trait t { fn fsync(l: level) -> int; }
 
     // Call o.fsync after executing blk
     fn obj_sync(&&o: t, opt_level: option<level>, blk: fn(&&res<t>)) {
@@ -250,7 +250,7 @@ fn FILE_reader(f: *libc::FILE, cleanup: bool) -> reader {
 }
 
-// FIXME (#2004): this should either be an iface-less impl, a set of
+// FIXME (#2004): this should either be an trait-less impl, a set of
 // top-level functions that take a reader, or a set of default methods on
 // reader (which can then be called reader)